clip_bbox package
================================


clip_bbox.clipbbox module
---------------------------------------------

.. automodule:: clip_bbox.clipbbox
   :members:
   :undoc-members:
   :show-inheritance:

clip_bbox.bbox_utils module
---------------------------------------------

.. automodule:: clip_bbox.bbox_utils
   :members:
   :undoc-members:
   :show-inheritance:

clip_bbox.clip_model_setup module
---------------------------------------------

.. automodule:: clip_bbox.clip_model_setup
   :members:
   :undoc-members:
   :show-inheritance:

clip_bbox.preprocess module
---------------------------------------------

.. automodule:: clip_bbox.preprocess
   :members:
   :undoc-members:
   :show-inheritance:
